# ckipneutools

author: Peng-Hsuan Li (jacobvsdanniel@gmail.com)

This is open-source neural implementation for
* CKIP-style Chinese word segmentation
* CKIP-style Chinese part-of-speech tagging
* CKIP-style Chinese named entity recognition

### License
CC BY-NC-SA 4.0
